var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
const eslint_1 = require("eslint");
const vscode_languageserver_textdocument_1 = require("vscode-languageserver-textdocument");
module.exports = function (program, resolveConfig) {
    var _a, _b, _c, _d, _e;
    return __awaiter(this, void 0, void 0, function* () {
        const tsProgram = program.__vue.languageService.__internal__.languageService.getProgram();
        const eslint = new eslint_1.ESLint({
            baseConfig: resolveConfig(tsProgram),
            useEslintrc: false,
        });
        const fileNames = program.__vue.languageServiceHost.getScriptFileNames();
        const mapper = program.__vue.languageService.__internal__.context.virtualFiles;
        const formatter = yield eslint.loadFormatter();
        for (const fileName of fileNames) {
            const vueFile = (_a = mapper.get(fileName)) === null || _a === void 0 ? void 0 : _a[1];
            if (vueFile) {
                const sourceDocument = vscode_languageserver_textdocument_1.TextDocument.create('', '', 0, vueFile.snapshot.getText(0, vueFile.snapshot.getLength()));
                const all = [];
                vueFile.embeddedFiles.forEach(function visit(embeddedFile) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (embeddedFile.capabilities.diagnostic) {
                            all.push(embeddedFile);
                        }
                        embeddedFile.embeddedFiles.forEach(visit);
                    });
                });
                for (const embeddedFile of all) {
                    const lintResult = yield eslint.lintText(embeddedFile.snapshot.getText(0, embeddedFile.snapshot.getLength()), { filePath: embeddedFile.fileName });
                    const embeddedDocument = vscode_languageserver_textdocument_1.TextDocument.create('', '', 0, embeddedFile.snapshot.getText(0, embeddedFile.snapshot.getLength()));
                    for (const result of lintResult) {
                        result.filePath = vueFile.fileName;
                        result.errorCount = 0;
                        result.warningCount = 0;
                        result.fixableErrorCount = 0;
                        result.fixableWarningCount = 0;
                        const messages = [];
                        for (const message of result.messages) {
                            if (!message.line || !message.column) {
                                message.line = 1;
                                message.column = 1;
                            }
                            const msgStart = embeddedDocument.offsetAt({
                                line: message.line - 1,
                                character: message.column - 1,
                            });
                            const msgEnd = embeddedDocument.offsetAt({
                                line: ((_b = message.endLine) !== null && _b !== void 0 ? _b : message.line) - 1,
                                character: ((_c = message.endColumn) !== null && _c !== void 0 ? _c : message.column) - 1,
                            });
                            for (const [sourceFileName, map] of mapper.getMaps(embeddedFile)) {
                                if (sourceFileName !== vueFile.fileName)
                                    continue;
                                for (const start of map.toSourceOffsets(msgStart)) {
                                    if (!start[1].data.diagnostic)
                                        continue;
                                    for (const end of map.toSourceOffsets(msgEnd, true)) {
                                        if (!end[1].data.diagnostic)
                                            continue;
                                        const range = {
                                            start: sourceDocument.positionAt(start[0]),
                                            end: sourceDocument.positionAt(end[0]),
                                        };
                                        messages.push(Object.assign(Object.assign({}, message), { line: range.start.line + 1, column: range.start.character + 1, endLine: range.end.line + 1, endColumn: range.end.character + 1 }));
                                        result.errorCount += message.severity === 2 ? 1 : 0;
                                        result.warningCount += message.severity === 1 ? 1 : 0;
                                        result.fixableErrorCount += message.severity === 2 && message.fix ? 1 : 0;
                                        result.fixableWarningCount += message.severity === 1 && message.fix ? 1 : 0;
                                        break;
                                    }
                                    break;
                                }
                            }
                        }
                        result.messages = messages;
                    }
                    const text = yield formatter.format(lintResult);
                    if (text) {
                        console.log(text);
                    }
                    break;
                }
            }
            else {
                const fileText = (_e = (_d = tsProgram === null || tsProgram === void 0 ? void 0 : tsProgram.getSourceFile(fileName)) === null || _d === void 0 ? void 0 : _d.text) !== null && _e !== void 0 ? _e : '';
                const lintResult = yield eslint.lintText(fileText, { filePath: fileName });
                const text = yield formatter.format(lintResult);
                if (text) {
                    console.log(text);
                }
            }
        }
    });
};
//# sourceMappingURL=index.js.map